@@ -1273,6 +1273,11 @@ flickcurl_invoke_photos_list(flickcurl* fc, const xmlChar* xpathExpr,
       goto tidy;
     }
 
+    if(!xpathObj->nodesetval || !xpathObj->nodesetval->nodeTab) {
+      /* No <photo> elements found in content - not a failure */
+      goto tidy;
+    }
+
     photos_node = xpathObj->nodesetval->nodeTab[0];
 
     xpathNodeCtx = xmlXPathNewContext(xpathCtx->doc);
@@ -1319,6 +1324,7 @@ flickcurl_invoke_photos_list(flickcurl* fc, const xmlChar* xpathExpr,
   
     photos_list->photos = flickcurl_build_photos(fc, xpathCtx, photosXpathExpr,
                                                  &photos_list->photos_count);
+    free(photosXpathExpr);
     if(!photos_list->photos) {
       fc->failed = 1;
       goto tidy;
