@@ -310,7 +310,7 @@ flickcurl_photos_comments_getRecentForContacts_params(flickcurl* fc,
     goto tidy;
 
   photos_list = flickcurl_invoke_photos_list(fc,
-                                             (const xmlChar*)"/rsp/photos/photo",
+                                             (const xmlChar*)"/rsp/photos",
                                              format);
 
   tidy:
